
From: Russell King <rmk+lkml@arm.linux.org.uk>

This patch cleans up needless includes of asm/pgalloc.h from the fs/
kernel/ and mm/ subtrees.  Compile tested on multiple ARM platforms, and
x86, this patch appears safe.

This patch is part of a larger patch aiming towards getting the include of
asm/pgtable.h out of linux/mm.h, so that asm/pgtable.h can sanely get at
things like mm_struct and friends.

I suggest testing in -mm for a while to ensure there aren't any hidden arch
issues.


---

 25-akpm/fs/binfmt_aout.c          |    1 -
 25-akpm/fs/binfmt_elf.c           |    1 -
 25-akpm/fs/binfmt_flat.c          |    1 -
 25-akpm/fs/exec.c                 |    1 -
 25-akpm/fs/proc/proc_misc.c       |    1 -
 25-akpm/include/asm-arm26/tlb.h   |    1 +
 25-akpm/include/asm-generic/tlb.h |    1 +
 25-akpm/kernel/module.c           |    1 -
 25-akpm/mm/highmem.c              |    1 -
 25-akpm/mm/mincore.c              |    1 -
 25-akpm/mm/mmap.c                 |    1 -
 25-akpm/mm/mprotect.c             |    1 -
 25-akpm/mm/mremap.c               |    1 -
 25-akpm/mm/msync.c                |    1 -
 25-akpm/mm/nommu.c                |    1 -
 25-akpm/mm/vmalloc.c              |    1 -
 25-akpm/mm/vmscan.c               |    1 -
 17 files changed, 2 insertions(+), 15 deletions(-)

diff -puN fs/binfmt_aout.c~clean-up-asm-pgalloch-include fs/binfmt_aout.c
--- 25/fs/binfmt_aout.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.727014688 -0700
+++ 25-akpm/fs/binfmt_aout.c	2004-05-04 20:55:23.751011040 -0700
@@ -27,7 +27,6 @@
 
 #include <asm/system.h>
 #include <asm/uaccess.h>
-#include <asm/pgalloc.h>
 #include <asm/cacheflush.h>
 
 static int load_aout_binary(struct linux_binprm *, struct pt_regs * regs);
diff -puN fs/binfmt_elf.c~clean-up-asm-pgalloch-include fs/binfmt_elf.c
--- 25/fs/binfmt_elf.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.729014384 -0700
+++ 25-akpm/fs/binfmt_elf.c	2004-05-04 20:55:23.752010888 -0700
@@ -40,7 +40,6 @@
 
 #include <asm/uaccess.h>
 #include <asm/param.h>
-#include <asm/pgalloc.h>
 
 #include <linux/elf.h>
 
diff -puN fs/binfmt_flat.c~clean-up-asm-pgalloch-include fs/binfmt_flat.c
--- 25/fs/binfmt_flat.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.730014232 -0700
+++ 25-akpm/fs/binfmt_flat.c	2004-05-04 20:55:23.753010736 -0700
@@ -40,7 +40,6 @@
 #include <asm/byteorder.h>
 #include <asm/system.h>
 #include <asm/uaccess.h>
-#include <asm/pgalloc.h>
 #include <asm/unaligned.h>
 #include <asm/cacheflush.h>
 
diff -puN fs/exec.c~clean-up-asm-pgalloch-include fs/exec.c
--- 25/fs/exec.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.732013928 -0700
+++ 25-akpm/fs/exec.c	2004-05-04 20:55:23.754010584 -0700
@@ -49,7 +49,6 @@
 #include <linux/mempolicy.h>
 
 #include <asm/uaccess.h>
-#include <asm/pgalloc.h>
 #include <asm/mmu_context.h>
 
 #ifdef CONFIG_KMOD
diff -puN fs/proc/proc_misc.c~clean-up-asm-pgalloch-include fs/proc/proc_misc.c
--- 25/fs/proc/proc_misc.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.733013776 -0700
+++ 25-akpm/fs/proc/proc_misc.c	2004-05-04 20:55:23.755010432 -0700
@@ -47,7 +47,6 @@
 #include <asm/uaccess.h>
 #include <asm/pgtable.h>
 #include <asm/io.h>
-#include <asm/pgalloc.h>
 #include <asm/tlb.h>
 #include <asm/div64.h>
 
diff -puN include/asm-arm26/tlb.h~clean-up-asm-pgalloch-include include/asm-arm26/tlb.h
--- 25/include/asm-arm26/tlb.h~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.734013624 -0700
+++ 25-akpm/include/asm-arm26/tlb.h	2004-05-04 20:55:23.755010432 -0700
@@ -1,6 +1,7 @@
 #ifndef __ASMARM_TLB_H
 #define __ASMARM_TLB_H
 
+#include <asm/pgalloc.h>
 #include <asm/tlbflush.h>
 
 /*
diff -puN include/asm-generic/tlb.h~clean-up-asm-pgalloch-include include/asm-generic/tlb.h
--- 25/include/asm-generic/tlb.h~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.735013472 -0700
+++ 25-akpm/include/asm-generic/tlb.h	2004-05-04 20:55:23.756010280 -0700
@@ -15,6 +15,7 @@
 
 #include <linux/config.h>
 #include <linux/swap.h>
+#include <asm/pgalloc.h>
 #include <asm/tlbflush.h>
 
 /*
diff -puN kernel/module.c~clean-up-asm-pgalloch-include kernel/module.c
--- 25/kernel/module.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.737013168 -0700
+++ 25-akpm/kernel/module.c	2004-05-04 20:55:23.757010128 -0700
@@ -36,7 +36,6 @@
 #include <linux/stop_machine.h>
 #include <asm/uaccess.h>
 #include <asm/semaphore.h>
-#include <asm/pgalloc.h>
 #include <asm/cacheflush.h>
 
 #if 0
diff -puN mm/highmem.c~clean-up-asm-pgalloch-include mm/highmem.c
--- 25/mm/highmem.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.738013016 -0700
+++ 25-akpm/mm/highmem.c	2004-05-04 20:55:23.757010128 -0700
@@ -26,7 +26,6 @@
 #include <linux/init.h>
 #include <linux/hash.h>
 #include <linux/highmem.h>
-#include <asm/pgalloc.h>
 #include <asm/tlbflush.h>
 
 static mempool_t *page_pool, *isa_page_pool;
diff -puN mm/mincore.c~clean-up-asm-pgalloch-include mm/mincore.c
--- 25/mm/mincore.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.739012864 -0700
+++ 25-akpm/mm/mincore.c	2004-05-04 20:55:23.758009976 -0700
@@ -14,7 +14,6 @@
 
 #include <asm/uaccess.h>
 #include <asm/pgtable.h>
-#include <asm/pgalloc.h>
 
 /*
  * Later we can get more picky about what "in core" means precisely.
diff -puN mm/mmap.c~clean-up-asm-pgalloch-include mm/mmap.c
--- 25/mm/mmap.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.741012560 -0700
+++ 25-akpm/mm/mmap.c	2004-05-04 20:55:36.909010720 -0700
@@ -24,7 +24,6 @@
 #include <linux/mempolicy.h>
 
 #include <asm/uaccess.h>
-#include <asm/pgalloc.h>
 #include <asm/cacheflush.h>
 #include <asm/tlb.h>
 
diff -puN mm/mprotect.c~clean-up-asm-pgalloch-include mm/mprotect.c
--- 25/mm/mprotect.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.742012408 -0700
+++ 25-akpm/mm/mprotect.c	2004-05-04 20:55:23.760009672 -0700
@@ -19,7 +19,6 @@
 #include <linux/mempolicy.h>
 
 #include <asm/uaccess.h>
-#include <asm/pgalloc.h>
 #include <asm/pgtable.h>
 #include <asm/cacheflush.h>
 #include <asm/tlbflush.h>
diff -puN mm/mremap.c~clean-up-asm-pgalloch-include mm/mremap.c
--- 25/mm/mremap.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.743012256 -0700
+++ 25-akpm/mm/mremap.c	2004-05-04 20:55:23.761009520 -0700
@@ -19,7 +19,6 @@
 #include <linux/security.h>
 
 #include <asm/uaccess.h>
-#include <asm/pgalloc.h>
 #include <asm/cacheflush.h>
 #include <asm/tlbflush.h>
 
diff -puN mm/msync.c~clean-up-asm-pgalloch-include mm/msync.c
--- 25/mm/msync.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.744012104 -0700
+++ 25-akpm/mm/msync.c	2004-05-04 20:55:23.761009520 -0700
@@ -13,7 +13,6 @@
 #include <linux/mman.h>
 
 #include <asm/pgtable.h>
-#include <asm/pgalloc.h>
 #include <asm/tlbflush.h>
 
 /*
diff -puN mm/nommu.c~clean-up-asm-pgalloch-include mm/nommu.c
--- 25/mm/nommu.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.745011952 -0700
+++ 25-akpm/mm/nommu.c	2004-05-04 20:55:23.762009368 -0700
@@ -19,7 +19,6 @@
 #include <linux/vmalloc.h>
 #include <linux/blkdev.h>
 
-#include <asm/pgalloc.h>
 #include <asm/uaccess.h>
 #include <asm/tlb.h>
 #include <asm/tlbflush.h>
diff -puN mm/vmalloc.c~clean-up-asm-pgalloch-include mm/vmalloc.c
--- 25/mm/vmalloc.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.747011648 -0700
+++ 25-akpm/mm/vmalloc.c	2004-05-04 20:55:23.762009368 -0700
@@ -17,7 +17,6 @@
 #include <linux/vmalloc.h>
 
 #include <asm/uaccess.h>
-#include <asm/pgalloc.h>
 #include <asm/tlbflush.h>
 
 
diff -puN mm/vmscan.c~clean-up-asm-pgalloch-include mm/vmscan.c
--- 25/mm/vmscan.c~clean-up-asm-pgalloch-include	2004-05-04 20:55:23.748011496 -0700
+++ 25-akpm/mm/vmscan.c	2004-05-04 20:55:23.763009216 -0700
@@ -33,7 +33,6 @@
 #include <linux/cpu.h>
 #include <linux/notifier.h>
 
-#include <asm/pgalloc.h>
 #include <asm/tlbflush.h>
 #include <asm/div64.h>
 

_
